@@ -1,16 +1,16 @@
 package CHI::CacheObject;
-use Storable;
 use strict;
 use warnings;
 
 use constant f_key              => 0;
 use constant f_raw_value        => 1;
-use constant f_created_at       => 2;
-use constant f_early_expires_at => 3;
-use constant f_expires_at       => 4;
-use constant f_is_serialized    => 5;
-use constant f_cache_version    => 6;
-use constant f_value            => 7;
+use constant f_serializer       => 2;
+use constant f_created_at       => 3;
+use constant f_early_expires_at => 4;
+use constant f_expires_at       => 5;
+use constant f_is_serialized    => 6;
+use constant f_cache_version    => 7;
+use constant f_value            => 8;
 
 my $Metadata_Format = "LLLCC";
 my $Metadata_Length = 14;
@@ -22,24 +22,27 @@ sub key              { $_[0]->[f_key] }
 sub created_at       { $_[0]->[f_created_at] }
 sub early_expires_at { $_[0]->[f_early_expires_at] }
 sub expires_at       { $_[0]->[f_expires_at] }
+sub serializer       { $_[0]->[f_serializer] }
 sub _is_serialized   { $_[0]->[f_is_serialized] }
 
 sub set_key              { $_[0]->[f_key]              = $_[1] }
 sub set_created_at       { $_[0]->[f_created_at]       = $_[1] }
 sub set_early_expires_at { $_[0]->[f_early_expires_at] = $_[1] }
 sub set_expires_at       { $_[0]->[f_expires_at]       = $_[1] }
+sub set_serializer       { $_[0]->[f_serializer]       = $_[1] }
 
 ## no critic (ProhibitManyArgs)
 sub new {
-    my ( $class, $key, $value, $created_at, $early_expires_at, $expires_at ) =
-      @_;
+    my ( $class, $key, $value, $created_at, $early_expires_at, $expires_at,
+        $serializer )
+      = @_;
 
     # Serialize value if necessary - does this belong here, or in Driver.pm?
     #
     my $is_serialized = 0;
     my $raw_value     = $value;
     if ( ref($raw_value) ) {
-        $raw_value     = $class->_serialize($raw_value);
+        $raw_value     = $serializer->serialize($raw_value);
         $is_serialized = 1;
     }
 
@@ -48,17 +51,21 @@ sub new {
     my $cache_version = 1;
 
     return bless [
-        $key,        $raw_value,     $created_at,    $early_expires_at,
-        $expires_at, $is_serialized, $cache_version, $value
+        $key,           $raw_value,        $serializer,
+        $created_at,    $early_expires_at, $expires_at,
+        $is_serialized, $cache_version,    $value,
     ], $class;
 }
 
 sub unpack_from_data {
-    my ( $class, $key, $data ) = @_;
+    my ( $class, $key, $data, $serializer ) = @_;
 
     my $metadata = substr( $data, 0, $Metadata_Length );
     my $raw_value = substr( $data, $Metadata_Length );
-    return bless [ $key, $raw_value, unpack( $Metadata_Format, $metadata ) ],
+    return bless [
+        $key, $raw_value,
+        $serializer, unpack( $Metadata_Format, $metadata )
+      ],
       $class;
 }
 
@@ -96,25 +103,13 @@ sub value {
     if ( !defined $self->[f_value] ) {
         my $value = $self->[f_raw_value];
         if ( $self->[f_is_serialized] ) {
-            $value = $self->_deserialize($value);
+            $value = $self->serializer->deserialize($value);
         }
         $self->[f_value] = $value;
     }
     return $self->[f_value];
 }
 
-sub _serialize {
-    my ( $self, $value ) = @_;
-
-    return Storable::freeze($value);
-}
-
-sub _deserialize {
-    my ( $self, $value ) = @_;
-
-    return Storable::thaw($value);
-}
-
 # get_* aliases for backward compatibility with Cache::Cache
 #
 *get_created_at = \&created_at;
@@ -146,6 +141,8 @@ CHI::CacheObject -- Contains information about cache entries.
 The L<CHI|get_object> method returns this object if the key exists.  The object will be
 returned even if the entry has expired, as long as it has not been removed.
 
+There is currently no public API for creating one of these objects directly.
+
 =head1 METHODS
 
 All methods are read-only. The get_* methods are provided for backward compatibility
