@@ -1,17 +1,14 @@
 package CHI::Driver::FastMmap;
+use Carp;
 use Cache::FastMmap;
-use CHI::Util qw(dp);
+use CHI::Util qw(read_dir);
 use File::Path qw(mkpath);
-use File::Slurp qw(read_dir);
 use File::Spec::Functions qw(catdir catfile splitdir tmpdir);
-use Moose;
+use Mouse;
 use strict;
 use warnings;
 
-extends 'CHI::Driver';
-
-with 'CHI::Driver::Role::CacheContainer' =>
-  { excludes => [qw( get_keys get_namespaces )] };
+extends 'CHI::Driver::Base::CacheContainer';
 
 has 'dir_create_mode' => ( is => 'ro', isa => 'Int', default => oct(775) );
 has 'root_dir' => (
@@ -20,9 +17,6 @@ has 'root_dir' => (
     default => catdir( tmpdir(), "chi-driver-fastmmap" )
 );
 
-__PACKAGE__->meta->alias_method(
-    'fm_cache' => __PACKAGE__->can('_contained_cache') );
-
 __PACKAGE__->meta->make_immutable();
 
 sub BUILD {
@@ -39,6 +33,7 @@ sub BUILD {
         ),
         %{ $self->non_common_constructor_params($params) },
     };
+    $self->{_contained_cache} = $self->_build_contained_cache;
 }
 
 sub _build_contained_cache {
@@ -47,6 +42,11 @@ sub _build_contained_cache {
     return Cache::FastMmap->new( %{ $self->{fm_params} } );
 }
 
+sub fm_cache {
+    my $self = shift;
+    return $self->_contained_cache(@_);
+}
+
 sub get_keys {
     my ($self) = @_;
 
@@ -65,6 +65,19 @@ sub get_namespaces {
     return @namespaces;
 }
 
+# Capture set failures
+sub store {
+    my $self   = shift;
+    my $result = $self->_contained_cache->set(@_);
+    if ( !$result ) {
+        my ( $key, $value ) = @_;
+        croak(
+            sprintf( "fastmmap set failed - value too large? (%d bytes)",
+                length($value) )
+        );
+    }
+}
+
 1;
 
 __END__
