@@ -14,6 +14,7 @@ our @EXPORT_OK = qw(
   fast_catdir
   fast_catfile
   parse_duration
+  read_dir
   require_dynamic
   unique_id
 );
@@ -40,6 +41,16 @@ sub dump_one_line {
       ->Terse(1)->Dump();
 }
 
+# Simplified read_dir cribbed from File::Slurp
+sub read_dir {
+    my ($dir) = @_;
+
+    ## no critic (RequireInitializationForLocalVars)
+    local *DIRH;
+    opendir( DIRH, $dir ) or croak "cannot open '$dir': $!";
+    return grep { $_ ne "." && $_ ne ".." } readdir(DIRH);
+}
+
 sub require_dynamic {
     my ($class) = @_;
 
